Learn R Programming

sgRSEA (version 0.1)

melanoma808: A subset of CRISPR/Cas9 knockout screening data on melanoma cell lines

Description

This is a subset of the data from a positive selection screening experiment on the melanoma cell lines by Shalem et al. (2014). It was obtained from Li et al. (2014).

Usage

data(melanoma808)

Arguments

Format

A data frame. Rows represent sgRNAs and columns are the sgRNA name, targeting gene name, and raw sgRNA read counts at sevel experimental conditions.

Li W, Xu H, Xiao T, Cong L, Love MI, Zhang F et al. (2014). MAGeCK enables robust identification of essential genes from genome-scale CRISPR/Cas9 knockout screens. Genome Biol. 15(12):554. Shalem O, Sanjana NE, Hartenian E, Shi X, Scott DA, Mikkelsen TS et al. (2014). Genome-scale CRISPR-Cas9 knockout screening in human cells. Science. 343(6166):84-7.

Examples

Run this code
data(melanoma808)

Run the code above in your browser using DataLab