sgRSEA.mean: Perform a permutation test similar to sgRSEA
Description
Perform the similar method to sgRSEA using a simple average instead of the maxmean statistic as gene level statistics. This method is referred as $T_{mean}$ in Noh et al. (2015+).
Usage
sgRSEA.mean(dat, multiplier = 50, r.seed = NULL)
Arguments
dat
A data.frame where rows represent sgRNAs and columns are the sgRNA name (1st), targeting gene name (2nd), and sgRNA read counts under treatment (3rd) and control (4th) condition.
multiplier
The number of permutations.
r.seed
A random seed to control the randomness of the permutation.
Value
Returns the same list as sgRSEA().
Details
Arguments and Value are the same as sgRSEA().
References
Noh, J., Chen, B., Xiao, G. and Xie, Y. (2015+). A robust test for identification of essential genes from CRISPR/Cas9 knockout screens.